# MAIN IMPORTS =============================================================================================================================================== #
import psyco
psyco.full()
import es
import os
import popuplib
import keyvalues
# ============================================================================================================================================================ #

# * SAM IMPORTS
func = es.import_addon('sam/functions')

# * VARIABLES

db     = 'sam_addons'
folder = 'sam/base/addons/'
dbfile = 'cstrike/cfg/sam/databases/es_%s_db.txt' % db
temp   = {}

# ============================================================================================================================================================ #
# ========================================================================== LOAD ============================================================================ #
# ============================================================================================================================================================ #
def load():
	### Load Database ###
	if checkDB(): es.keygroupload(db, func.dbfiles)

	### Load Addons ###
	for x in getAddons():
		if not isreg(x): register(x)
		else:
			addon = getAddon(x)
			if int(addon['status']) == 1: es.load(folder + addon['basename'])

# ============================================================================================================================================================ #
# ========================================================================= UNLOAD =========================================================================== #
# ============================================================================================================================================================ #
def unload():
	### Unloads ###
	for x in getAddons():
		if isreg(x):
			addon = getAddon(x)
			if int(addon['status']) == 0: es.unload(folder + addon['basename'])

	### Deletes ###
	es.keygroupdelete(db)

	### Popups ###
	func.popupDelete('getAddons')
	func.popupDelete('monitor')

# ============================================================================================================================================================ #
# ======================================================================= MAIN BLOCKS ======================================================================== #
# ============================================================================================================================================================ #
def modulePopup(userid):
	func.popupDelete('getAddons')
	popup = popuplib.easymenu('getAddons', None, addonMonitor)
	popup.c_beginsep = func.pline
	popup.c_pagesep  = func.pline
	popup.settitle('%s | SAM %s' % (func.menutitle, es.ServerVar('sam_version')))
	popup.setdescription('\n \n :: %s\n # %s' % (func.lang_titles('addons_name'), func.lang_titles('addons_addonsList_desc')))
	for x in getAddons():
		if not isreg(x): register(x)
		addon = getAddon(x)
		popup.addoption(addon, addon['name'])
	popup.submenu(10, 'mainPage')
	popup.send(userid)

# ------------------------------------------------------------------------------------------------------------------------------------------------------------ #
def addonMonitor(userid, addon, popup):
	temp[userid] = addon
	func.popupDelete('monitor')
	popup = popuplib.create('monitor')
	popup.addline('%s | SAM %s' % (func.menutitle, es.ServerVar('sam_version')))
	popup.addline('\n \n :: %s' % func.lang_titles('addons_name'))
	popup.addline(func.pline)
	popup.addline('   # Addon: %s' % addon['name'])
	popup.addline('   # %s: %s' % (func.lang_word('version'),addon['version']))
	popup.addline(' \n- %s' % func.lang_addonsDesc(addon['basename']))
	popup.addline(func.pline)
	if int(addon['status']) == 1: popup.addline('->1. %s: [ %s ] :  %s  :' % (func.lang_word('status').upper(),func.lang_word('on'),func.lang_word('off')))
	else: popup.addline('->1. %s:  %s  : [ %s ] :' % (func.lang_word('status').upper(),func.lang_word('on'),func.lang_word('off')))
	popup.addline(func.pline)
	popup.addline('->8. %s' % func.lang_word('back'))
	popup.addline('->0. %s' % func.lang_word('cancel'))
	popup.menuselect = addonMonitor_choice
	popup.send(userid)

# ------------------------------------------------------------------------------------------------------------------------------------------------------------ #
def addonMonitor_choice(userid, choice, popup):
	addon = temp[userid]
	if choice in range(1,8):
		if choice == 1:
			if int(addon['status']) == 1:
				es.unload('sam/base/addons/' + addon['basename'])
				es.keysetvalue(db, addon['basename'], 'status', 0)
			elif int(addon['status']) == 0:
				es.load('sam/base/addons/' + addon['basename'])
				es.keysetvalue(db, addon['basename'], 'status', 1)
			es.keygroupsave(db, func.dbfiles)
		addonMonitor(userid, getAddon(addon['basename']), None)
	elif choice == 8: modulePopup(userid)
	elif choice in (8,9,10): func.popupDelete(popup)

# ============================================================================================================================================================ #
# ======================================================================== FUNCTIONS ========================================================================= #
# ============================================================================================================================================================ #
def register(addon):
	if not es.exists('keygroup', db): es.keygroupcreate(db)
	if not es.exists('key', db, addon):
		es.load(folder + addon)
		block = es.import_addon(folder + addon)
		es.keycreate(db, addon)
		es.keysetvalue(db, addon, 'name', block.addon.name)
		es.keysetvalue(db, addon, 'version', block.addon.version)
		es.keysetvalue(db, addon, 'basename', block.addon.basename)
		es.keysetvalue(db, addon, 'status', block.addon.status)
		es.keygroupsave(db, func.dbfiles)
		if block.addon.status == 0: es.unload(folder + addon)

# :::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::: #
def isreg(addon):
	if checkDB():
		if es.exists('keygroup', db):
			if es.exists('key', db, addon): return True
			else: return False
		else: return False
	else: return False

# :::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::: #
def getAddon(addon):
	return {'name':es.keygetvalue(db, addon, 'name'),'version':es.keygetvalue(db, addon, 'version'),
			'basename':es.keygetvalue(db, addon, 'basename'),'status':es.keygetvalue(db, addon, 'status')}

# :::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::: #
def getAddons():
	addons = []
	dir    = es.getAddonPath('sam') + '/base/addons'
	for item in os.listdir(dir):
		if os.path.isdir(dir + '/' + item) == True: addons.append(item)
	return addons

# :::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::: #
def checkDB():
	if os.path.isfile(dbfile): return True
	else: return False

# ============================================================================================================================================================ #